
package com.gridnine.xtrip.server.gds.s7ndc.wsmodel050;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

/** 
 * COUPON FLIGHT SEGMENT definition.
 * 
 * Schema fragment(s) for this class:
 * <pre>
 * &lt;xs:complexType xmlns:ns="http://www.iata.org/IATA/EDIST" xmlns:xs="http://www.w3.org/2001/XMLSchema" name="CouponFlightSegmentType">
 *   &lt;xs:complexContent>
 *     &lt;xs:extension base="ns:KeyWithMetaObjectBaseType">
 *       &lt;xs:sequence>
 *         &lt;xs:element type="xs:string" name="InfoSource" minOccurs="0"/>
 *         &lt;xs:element type="ns:CoreDateGrpType" name="DepartureDateTime" minOccurs="0"/>
 *         &lt;xs:element type="xs:string" name="TourOperatorFlightID" minOccurs="0"/>
 *         &lt;xs:element ref="ns:Departure" minOccurs="0"/>
 *         &lt;xs:element ref="ns:Arrival" minOccurs="0"/>
 *         &lt;xs:element name="OperatingCarrier" minOccurs="0">
 *           &lt;!-- Reference to inner class OperatingCarrier -->
 *         &lt;/xs:element>
 *         &lt;xs:element type="ns:MarketingCarrierFlightType" name="MarketingCarrier" minOccurs="0"/>
 *         &lt;xs:element ref="ns:Equipment" minOccurs="0" maxOccurs="2"/>
 *         &lt;xs:element type="ns:CodesetType" name="InvoluntaryIndicatorCode" minOccurs="0"/>
 *       &lt;/xs:sequence>
 *     &lt;/xs:extension>
 *   &lt;/xs:complexContent>
 * &lt;/xs:complexType>
 * </pre>
 */
public class CouponFlightSegmentType extends KeyWithMetaObjectBaseType
    implements Serializable
{
    private String infoSource;
    private CoreDateGrpType departureDateTime;
    private String tourOperatorFlightID;
    private FlightDepartureType departure;
    private FlightArrivalType arrival;
    private OperatingCarrier operatingCarrier;
    private MarketingCarrierFlightType marketingCarrier;
    private List<Equipment> equipmentList = new ArrayList<Equipment>();
    private CodesetType involuntaryIndicatorCode;

    /** 
     * Get the 'InfoSource' element value. Information Source. Example: BA
     * 
     * @return value
     */
    public String getInfoSource() {
        return infoSource;
    }

    /** 
     * Set the 'InfoSource' element value. Information Source. Example: BA
     * 
     * @param infoSource
     */
    public void setInfoSource(String infoSource) {
        this.infoSource = infoSource;
    }

    /** 
     * Get the 'DepartureDateTime' element value. Scheduled, intended or actual departure date/ time.
     * 
     * @return value
     */
    public CoreDateGrpType getDepartureDateTime() {
        return departureDateTime;
    }

    /** 
     * Set the 'DepartureDateTime' element value. Scheduled, intended or actual departure date/ time.
     * 
     * @param departureDateTime
     */
    public void setDepartureDateTime(CoreDateGrpType departureDateTime) {
        this.departureDateTime = departureDateTime;
    }

    /** 
     * Get the 'TourOperatorFlightID' element value. Tour Operator Flight ID.

    Note: This is an ID for the flight as represented by a Tour Operator. This flight is not necessarily in the inventory of an airline as it is a code created by tour operators.  
     * 
     * @return value
     */
    public String getTourOperatorFlightID() {
        return tourOperatorFlightID;
    }

    /** 
     * Set the 'TourOperatorFlightID' element value. Tour Operator Flight ID.

    Note: This is an ID for the flight as represented by a Tour Operator. This flight is not necessarily in the inventory of an airline as it is a code created by tour operators.  
     * 
     * @param tourOperatorFlightID
     */
    public void setTourOperatorFlightID(String tourOperatorFlightID) {
        this.tourOperatorFlightID = tourOperatorFlightID;
    }

    /** 
     * Get the 'Departure' element value.
     * 
     * @return value
     */
    public FlightDepartureType getDeparture() {
        return departure;
    }

    /** 
     * Set the 'Departure' element value.
     * 
     * @param departure
     */
    public void setDeparture(FlightDepartureType departure) {
        this.departure = departure;
    }

    /** 
     * Get the 'Arrival' element value.
     * 
     * @return value
     */
    public FlightArrivalType getArrival() {
        return arrival;
    }

    /** 
     * Set the 'Arrival' element value.
     * 
     * @param arrival
     */
    public void setArrival(FlightArrivalType arrival) {
        this.arrival = arrival;
    }

    /** 
     * Get the 'OperatingCarrier' element value.
     * 
     * @return value
     */
    public OperatingCarrier getOperatingCarrier() {
        return operatingCarrier;
    }

    /** 
     * Set the 'OperatingCarrier' element value.
     * 
     * @param operatingCarrier
     */
    public void setOperatingCarrier(OperatingCarrier operatingCarrier) {
        this.operatingCarrier = operatingCarrier;
    }

    /** 
     * Get the 'MarketingCarrier' element value. Marketing Carrier and Flight Number information.

    Notes: This is the carrier that sells with its own code as part of a code share agreement on a flight that is actually operated by another carrier.
     * 
     * @return value
     */
    public MarketingCarrierFlightType getMarketingCarrier() {
        return marketingCarrier;
    }

    /** 
     * Set the 'MarketingCarrier' element value. Marketing Carrier and Flight Number information.

    Notes: This is the carrier that sells with its own code as part of a code share agreement on a flight that is actually operated by another carrier.
     * 
     * @param marketingCarrier
     */
    public void setMarketingCarrier(MarketingCarrierFlightType marketingCarrier) {
        this.marketingCarrier = marketingCarrier;
    }

    /** 
     * Get the list of 'Equipment' element items. Aircraft Equipment.

    Note: Two instances of aircraft equipment may be specified if there is a change of gauge.
     * 
     * @return list
     */
    public List<Equipment> getEquipmentList() {
        return equipmentList;
    }

    /** 
     * Set the list of 'Equipment' element items. Aircraft Equipment.

    Note: Two instances of aircraft equipment may be specified if there is a change of gauge.
     * 
     * @param list
     */
    public void setEquipmentList(List<Equipment> list) {
        equipmentList = list;
    }

    /** 
     * Get the 'InvoluntaryIndicatorCode' element value. Involuntary Change Transaction Code. Example: I (Involuntary - no reason given)

    Encoding Scheme: IATA Padis Codeset - List for data element 1245 (Status indicator, coded)
     * 
     * @return value
     */
    public CodesetType getInvoluntaryIndicatorCode() {
        return involuntaryIndicatorCode;
    }

    /** 
     * Set the 'InvoluntaryIndicatorCode' element value. Involuntary Change Transaction Code. Example: I (Involuntary - no reason given)

    Encoding Scheme: IATA Padis Codeset - List for data element 1245 (Status indicator, coded)
     * 
     * @param involuntaryIndicatorCode
     */
    public void setInvoluntaryIndicatorCode(CodesetType involuntaryIndicatorCode) {
        this.involuntaryIndicatorCode = involuntaryIndicatorCode;
    }
    /** 
     * Operating Carrier Information.

    Operating Carrier is the carrier that operates a flight with a reference to its own prime flight number.

    Note: Operating Carrier may be different from a Marketing Carrier(s), if the flight is actually marketed by another carrier(s) within a codeshare agreement. 

    Operating Carrier may not be the AOC holder, in which case, and wherever required, this will need to be disclosed to the customer.
     * 
     * Schema fragment(s) for this class:
     * <pre>
     * &lt;xs:element xmlns:ns="http://www.iata.org/IATA/EDIST" xmlns:xs="http://www.w3.org/2001/XMLSchema" name="OperatingCarrier" minOccurs="0">
     *   &lt;xs:complexType>
     *     &lt;xs:complexContent>
     *       &lt;xs:extension base="ns:OperatingCarrierFlightType">
     *         &lt;xs:sequence>
     *           &lt;xs:element ref="ns:Disclosures" minOccurs="0"/>
     *         &lt;/xs:sequence>
     *       &lt;/xs:extension>
     *     &lt;/xs:complexContent>
     *   &lt;/xs:complexType>
     * &lt;/xs:element>
     * </pre>
     */
    public static class OperatingCarrier extends OperatingCarrierFlightType
        implements Serializable
    {
        private DisclosureType disclosures;

        /** 
         * Get the 'Disclosures' element value.
         * 
         * @return value
         */
        public DisclosureType getDisclosures() {
            return disclosures;
        }

        /** 
         * Set the 'Disclosures' element value.
         * 
         * @param disclosures
         */
        public void setDisclosures(DisclosureType disclosures) {
            this.disclosures = disclosures;
        }
    }
}
