
package com.gridnine.xtrip.server.gds.s7ndc.wsmodel050;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

/** 
 * PAYMENT METHOD definition.
 * 
 * Schema fragment(s) for this class:
 * <pre>
 * &lt;xs:complexType xmlns:ns="http://www.iata.org/IATA/EDIST" xmlns:xs="http://www.w3.org/2001/XMLSchema" name="PaymentMethodType">
 *   &lt;xs:sequence>
 *     &lt;xs:element name="Method" maxOccurs="unbounded">
 *       &lt;!-- Reference to inner class Method -->
 *     &lt;/xs:element>
 *   &lt;/xs:sequence>
 * &lt;/xs:complexType>
 * </pre>
 */
public class PaymentMethodType implements Serializable
{
    private List<Method> methodList = new ArrayList<Method>();

    /** 
     * Get the list of 'Method' element items.
     * 
     * @return list
     */
    public List<Method> getMethodList() {
        return methodList;
    }

    /** 
     * Set the list of 'Method' element items.
     * 
     * @param list
     */
    public void setMethodList(List<Method> list) {
        methodList = list;
    }
    /** 
     * Payment Method detail.
     * 
     * Schema fragment(s) for this class:
     * <pre>
     * &lt;xs:element xmlns:ns="http://www.iata.org/IATA/EDIST" xmlns:xs="http://www.w3.org/2001/XMLSchema" name="Method" maxOccurs="unbounded">
     *   &lt;xs:complexType>
     *     &lt;xs:complexContent>
     *       &lt;xs:extension base="ns:KeyWithMetaObjectBaseType">
     *         &lt;xs:sequence>
     *           &lt;xs:element type="ns:CodesetType" name="Qualifier" minOccurs="0"/>
     *           &lt;xs:element ref="ns:VoucherMethod" minOccurs="0"/>
     *           &lt;xs:element ref="ns:RedemptionMethod" minOccurs="0"/>
     *           &lt;xs:element ref="ns:PaymentCardMethod" minOccurs="0"/>
     *           &lt;xs:element ref="ns:OtherMethod" minOccurs="0"/>
     *           &lt;xs:element ref="ns:MiscChargeMethod" minOccurs="0"/>
     *           &lt;xs:element ref="ns:DirectBillMethod" minOccurs="0"/>
     *           &lt;xs:element ref="ns:CashMethod" minOccurs="0"/>
     *           &lt;xs:element ref="ns:BankAccountMethod" minOccurs="0"/>
     *           &lt;xs:element ref="ns:Cheque" minOccurs="0"/>
     *           &lt;xs:element name="Promotions" minOccurs="0">
     *             &lt;!-- Reference to inner class Promotions -->
     *           &lt;/xs:element>
     *         &lt;/xs:sequence>
     *       &lt;/xs:extension>
     *     &lt;/xs:complexContent>
     *   &lt;/xs:complexType>
     * &lt;/xs:element>
     * </pre>
     */
    public static class Method extends KeyWithMetaObjectBaseType implements
        Serializable
    {
        private CodesetType qualifier;
        private VoucherMethodType voucherMethod;
        private RedemptionMethodType redemptionMethod;
        private PaymentCardMethodType paymentCardMethod;
        private OtherMethodType otherMethod;
        private MiscChargeMethodType miscChargeMethod;
        private DirectBillMethodType directBillMethod;
        private CashMethodType cashMethod;
        private BankAccountMethodType bankAccountMethod;
        private Cheque cheque;
        private Promotions promotions;

        /** 
         * Get the 'Qualifier' element value. Used to specify if this is the old, new, or orginal form of payment.

        Encoding Scheme: IATA  PADIS code list 9988 - Data Indicator
         * 
         * @return value
         */
        public CodesetType getQualifier() {
            return qualifier;
        }

        /** 
         * Set the 'Qualifier' element value. Used to specify if this is the old, new, or orginal form of payment.

        Encoding Scheme: IATA  PADIS code list 9988 - Data Indicator
         * 
         * @param qualifier
         */
        public void setQualifier(CodesetType qualifier) {
            this.qualifier = qualifier;
        }

        /** 
         * Get the 'VoucherMethod' element value.
         * 
         * @return value
         */
        public VoucherMethodType getVoucherMethod() {
            return voucherMethod;
        }

        /** 
         * Set the 'VoucherMethod' element value.
         * 
         * @param voucherMethod
         */
        public void setVoucherMethod(VoucherMethodType voucherMethod) {
            this.voucherMethod = voucherMethod;
        }

        /** 
         * Get the 'RedemptionMethod' element value.
         * 
         * @return value
         */
        public RedemptionMethodType getRedemptionMethod() {
            return redemptionMethod;
        }

        /** 
         * Set the 'RedemptionMethod' element value.
         * 
         * @param redemptionMethod
         */
        public void setRedemptionMethod(RedemptionMethodType redemptionMethod) {
            this.redemptionMethod = redemptionMethod;
        }

        /** 
         * Get the 'PaymentCardMethod' element value.
         * 
         * @return value
         */
        public PaymentCardMethodType getPaymentCardMethod() {
            return paymentCardMethod;
        }

        /** 
         * Set the 'PaymentCardMethod' element value.
         * 
         * @param paymentCardMethod
         */
        public void setPaymentCardMethod(PaymentCardMethodType paymentCardMethod) {
            this.paymentCardMethod = paymentCardMethod;
        }

        /** 
         * Get the 'OtherMethod' element value.
         * 
         * @return value
         */
        public OtherMethodType getOtherMethod() {
            return otherMethod;
        }

        /** 
         * Set the 'OtherMethod' element value.
         * 
         * @param otherMethod
         */
        public void setOtherMethod(OtherMethodType otherMethod) {
            this.otherMethod = otherMethod;
        }

        /** 
         * Get the 'MiscChargeMethod' element value.
         * 
         * @return value
         */
        public MiscChargeMethodType getMiscChargeMethod() {
            return miscChargeMethod;
        }

        /** 
         * Set the 'MiscChargeMethod' element value.
         * 
         * @param miscChargeMethod
         */
        public void setMiscChargeMethod(MiscChargeMethodType miscChargeMethod) {
            this.miscChargeMethod = miscChargeMethod;
        }

        /** 
         * Get the 'DirectBillMethod' element value.
         * 
         * @return value
         */
        public DirectBillMethodType getDirectBillMethod() {
            return directBillMethod;
        }

        /** 
         * Set the 'DirectBillMethod' element value.
         * 
         * @param directBillMethod
         */
        public void setDirectBillMethod(DirectBillMethodType directBillMethod) {
            this.directBillMethod = directBillMethod;
        }

        /** 
         * Get the 'CashMethod' element value.
         * 
         * @return value
         */
        public CashMethodType getCashMethod() {
            return cashMethod;
        }

        /** 
         * Set the 'CashMethod' element value.
         * 
         * @param cashMethod
         */
        public void setCashMethod(CashMethodType cashMethod) {
            this.cashMethod = cashMethod;
        }

        /** 
         * Get the 'BankAccountMethod' element value.
         * 
         * @return value
         */
        public BankAccountMethodType getBankAccountMethod() {
            return bankAccountMethod;
        }

        /** 
         * Set the 'BankAccountMethod' element value.
         * 
         * @param bankAccountMethod
         */
        public void setBankAccountMethod(BankAccountMethodType bankAccountMethod) {
            this.bankAccountMethod = bankAccountMethod;
        }

        /** 
         * Get the 'Cheque' element value.
         * 
         * @return value
         */
        public Cheque getCheque() {
            return cheque;
        }

        /** 
         * Set the 'Cheque' element value.
         * 
         * @param cheque
         */
        public void setCheque(Cheque cheque) {
            this.cheque = cheque;
        }

        /** 
         * Get the 'Promotions' element value.
         * 
         * @return value
         */
        public Promotions getPromotions() {
            return promotions;
        }

        /** 
         * Set the 'Promotions' element value.
         * 
         * @param promotions
         */
        public void setPromotions(Promotions promotions) {
            this.promotions = promotions;
        }
        /** 
         * Applied Promotions for this payment form.

        Note: If specified, this individual payment form information will override any globally specified promotion information.
         * 
         * Schema fragment(s) for this class:
         * <pre>
         * &lt;xs:element xmlns:ns="http://www.iata.org/IATA/EDIST" xmlns:xs="http://www.w3.org/2001/XMLSchema" name="Promotions" minOccurs="0">
         *   &lt;xs:complexType>
         *     &lt;xs:sequence>
         *       &lt;xs:element name="Promotion" maxOccurs="unbounded">
         *         &lt;!-- Reference to inner class Promotion -->
         *       &lt;/xs:element>
         *     &lt;/xs:sequence>
         *   &lt;/xs:complexType>
         * &lt;/xs:element>
         * </pre>
         */
        public static class Promotions implements Serializable
        {
            private List<Promotion> promotionList = new ArrayList<Promotion>();

            /** 
             * Get the list of 'Promotion' element items.
             * 
             * @return list
             */
            public List<Promotion> getPromotionList() {
                return promotionList;
            }

            /** 
             * Set the list of 'Promotion' element items.
             * 
             * @param list
             */
            public void setPromotionList(List<Promotion> list) {
                promotionList = list;
            }
            /** 
             * Promotion Detail.
             * 
             * Schema fragment(s) for this class:
             * <pre>
             * &lt;xs:element xmlns:ns="http://www.iata.org/IATA/EDIST" xmlns:xs="http://www.w3.org/2001/XMLSchema" name="Promotion" maxOccurs="unbounded">
             *   &lt;xs:complexType>
             *     &lt;xs:complexContent>
             *       &lt;xs:extension base="ns:PromotionType">
             *         &lt;xs:sequence>
             *           &lt;xs:element ref="ns:Associations"/>
             *         &lt;/xs:sequence>
             *       &lt;/xs:extension>
             *     &lt;/xs:complexContent>
             *   &lt;/xs:complexType>
             * &lt;/xs:element>
             * </pre>
             */
            public static class Promotion extends PromotionType implements
                Serializable
            {
                private Associations associations;

                /** 
                 * Get the 'Associations' element value. Association(s), including Passenger and Group.
                 * 
                 * @return value
                 */
                public Associations getAssociations() {
                    return associations;
                }

                /** 
                 * Set the 'Associations' element value. Association(s), including Passenger and Group.
                 * 
                 * @param associations
                 */
                public void setAssociations(Associations associations) {
                    this.associations = associations;
                }
            }
        }
    }
}
