
package com.gridnine.xtrip.server.gds.s7ndc.wsmodel050;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

/** 
 * Service Price Response Message Parameters.
 * 
 * Schema fragment(s) for this class:
 * <pre>
 * &lt;xs:complexType xmlns:ns="http://www.iata.org/IATA/EDIST" xmlns:xs="http://www.w3.org/2001/XMLSchema" name="SrvPriceResParamsType">
 *   &lt;xs:complexContent>
 *     &lt;xs:extension base="ns:MessageParamsBaseType">
 *       &lt;xs:sequence>
 *         &lt;xs:element name="Pricing" minOccurs="0">
 *           &lt;!-- Reference to inner class Pricing -->
 *         &lt;/xs:element>
 *         &lt;xs:element ref="ns:InventoryGuarantee" minOccurs="0"/>
 *         &lt;xs:element name="Group" minOccurs="0">
 *           &lt;xs:complexType>
 *             &lt;xs:sequence>
 *               &lt;xs:element ref="ns:PrimaryContact" minOccurs="0"/>
 *             &lt;/xs:sequence>
 *           &lt;/xs:complexType>
 *         &lt;/xs:element>
 *       &lt;/xs:sequence>
 *     &lt;/xs:extension>
 *   &lt;/xs:complexContent>
 * &lt;/xs:complexType>
 * </pre>
 */
public class SrvPriceResParamsType extends MessageParamsBaseType implements
    Serializable
{
    private Pricing pricing;
    private InvGuaranteeType inventoryGuarantee;
    private PrimaryContact group;

    /** 
     * Get the 'Pricing' element value.
     * 
     * @return value
     */
    public Pricing getPricing() {
        return pricing;
    }

    /** 
     * Set the 'Pricing' element value.
     * 
     * @param pricing
     */
    public void setPricing(Pricing pricing) {
        this.pricing = pricing;
    }

    /** 
     * Get the 'InventoryGuarantee' element value. Inventory Guarantee information, including Inventory Guarantee Time Limit, Unique ID and Offer/ Offer Item association(s).

    Notes:
    1. This is the time that inventory for a specified product offer is guaranteed as available. The inventory held must be converted into a completed order before the time limit expires otherwise the guarantee is lost.
    2. If specified, an association to one or more Offers or Offer Items may be specified in the Associations node. If no associations are specified, the inventory guarantee is assumed to apply to the entire Offer.
    3. This capability may not be supported by all NDC-enabled systems or may be supported by bilateral agreement only. If supported, the technical implementation of this capability is not dictated by this specification.
     * 
     * @return value
     */
    public InvGuaranteeType getInventoryGuarantee() {
        return inventoryGuarantee;
    }

    /** 
     * Set the 'InventoryGuarantee' element value. Inventory Guarantee information, including Inventory Guarantee Time Limit, Unique ID and Offer/ Offer Item association(s).

    Notes:
    1. This is the time that inventory for a specified product offer is guaranteed as available. The inventory held must be converted into a completed order before the time limit expires otherwise the guarantee is lost.
    2. If specified, an association to one or more Offers or Offer Items may be specified in the Associations node. If no associations are specified, the inventory guarantee is assumed to apply to the entire Offer.
    3. This capability may not be supported by all NDC-enabled systems or may be supported by bilateral agreement only. If supported, the technical implementation of this capability is not dictated by this specification.
     * 
     * @param inventoryGuarantee
     */
    public void setInventoryGuarantee(InvGuaranteeType inventoryGuarantee) {
        this.inventoryGuarantee = inventoryGuarantee;
    }

    /** 
     * Get the 'PrimaryContact' element value. Group-related Offer Information.
     * 
     * @return value
     */
    public PrimaryContact getGroup() {
        return group;
    }

    /** 
     * Set the 'PrimaryContact' element value. Group-related Offer Information.
     * 
     * @param group
     */
    public void setGroup(PrimaryContact group) {
        this.group = group;
    }
    /** 
     * Pricing Parameters, including Simple Pricing, Award Travel, Auto Exchange, Override Currency and Fee Exemption.
     * 
     * Schema fragment(s) for this class:
     * <pre>
     * &lt;xs:element xmlns:ns="http://www.iata.org/IATA/EDIST" xmlns:xs="http://www.w3.org/2001/XMLSchema" name="Pricing" minOccurs="0">
     *   &lt;xs:complexType>
     *     &lt;xs:sequence>
     *       &lt;xs:element type="xs:string" name="OverrideCurrency" minOccurs="0"/>
     *       &lt;xs:element name="FeeExemption" minOccurs="0">
     *         &lt;!-- Reference to inner class FeeExemption -->
     *       &lt;/xs:element>
     *     &lt;/xs:sequence>
     *     &lt;xs:attribute type="xs:boolean" use="optional" name="AutoExchangeInd"/>
     *     &lt;xs:attribute type="xs:boolean" use="optional" name="AwardIncludedInd"/>
     *     &lt;xs:attribute type="xs:boolean" use="optional" name="AwardOnlyInd"/>
     *     &lt;xs:attribute type="xs:boolean" use="optional" name="SimpleInd"/>
     *   &lt;/xs:complexType>
     * &lt;/xs:element>
     * </pre>
     */
    public static class Pricing implements Serializable
    {
        private String overrideCurrency;
        private FeeExemption feeExemption;
        private Boolean autoExchangeInd;
        private Boolean awardIncludedInd;
        private Boolean awardOnlyInd;
        private Boolean simpleInd;

        /** 
         * Get the 'OverrideCurrency' element value. Requested override currency code for pricing.
        Example: EUR
         * 
         * @return value
         */
        public String getOverrideCurrency() {
            return overrideCurrency;
        }

        /** 
         * Set the 'OverrideCurrency' element value. Requested override currency code for pricing.
        Example: EUR
         * 
         * @param overrideCurrency
         */
        public void setOverrideCurrency(String overrideCurrency) {
            this.overrideCurrency = overrideCurrency;
        }

        /** 
         * Get the 'FeeExemption' element value.
         * 
         * @return value
         */
        public FeeExemption getFeeExemption() {
            return feeExemption;
        }

        /** 
         * Set the 'FeeExemption' element value.
         * 
         * @param feeExemption
         */
        public void setFeeExemption(FeeExemption feeExemption) {
            this.feeExemption = feeExemption;
        }

        /** 
         * Get the 'AutoExchangeInd' attribute value. When TRUE, fare information for one or more Offer Items has been returned from an auto-exchanging application.
         * 
         * @return value
         */
        public Boolean getAutoExchangeInd() {
            return autoExchangeInd;
        }

        /** 
         * Set the 'AutoExchangeInd' attribute value. When TRUE, fare information for one or more Offer Items has been returned from an auto-exchanging application.
         * 
         * @param autoExchangeInd
         */
        public void setAutoExchangeInd(Boolean autoExchangeInd) {
            this.autoExchangeInd = autoExchangeInd;
        }

        /** 
         * Get the 'AwardIncludedInd' attribute value. When TRUE, award eligible in addition to priced offers and fares is requested.
         * 
         * @return value
         */
        public Boolean getAwardIncludedInd() {
            return awardIncludedInd;
        }

        /** 
         * Set the 'AwardIncludedInd' attribute value. When TRUE, award eligible in addition to priced offers and fares is requested.
         * 
         * @param awardIncludedInd
         */
        public void setAwardIncludedInd(Boolean awardIncludedInd) {
            this.awardIncludedInd = awardIncludedInd;
        }

        /** 
         * Get the 'AwardOnlyInd' attribute value. When TRUE, only award eligible offers/ fares have been returned.
         * 
         * @return value
         */
        public Boolean getAwardOnlyInd() {
            return awardOnlyInd;
        }

        /** 
         * Set the 'AwardOnlyInd' attribute value. When TRUE, only award eligible offers/ fares have been returned.
         * 
         * @param awardOnlyInd
         */
        public void setAwardOnlyInd(Boolean awardOnlyInd) {
            this.awardOnlyInd = awardOnlyInd;
        }

        /** 
         * Get the 'SimpleInd' attribute value. When TRUE, Simple Pricing  for flight offers has been applied.
         * 
         * @return value
         */
        public Boolean getSimpleInd() {
            return simpleInd;
        }

        /** 
         * Set the 'SimpleInd' attribute value. When TRUE, Simple Pricing  for flight offers has been applied.
         * 
         * @param simpleInd
         */
        public void setSimpleInd(Boolean simpleInd) {
            this.simpleInd = simpleInd;
        }
        /** 
         * Fee exemption application for Offer pricing.
         * 
         * Schema fragment(s) for this class:
         * <pre>
         * &lt;xs:element xmlns:ns="http://www.iata.org/IATA/EDIST" xmlns:xs="http://www.w3.org/2001/XMLSchema" name="FeeExemption" minOccurs="0">
         *   &lt;xs:complexType>
         *     &lt;xs:complexContent>
         *       &lt;xs:extension base="ns:AssociatedObjectBaseType">
         *         &lt;xs:sequence>
         *           &lt;xs:element name="Fee" minOccurs="0" maxOccurs="unbounded">
         *             &lt;!-- Reference to inner class Fee -->
         *           &lt;/xs:element>
         *           &lt;xs:element ref="ns:CountryCode" minOccurs="0" maxOccurs="unbounded"/>
         *           &lt;xs:element type="xs:string" name="ProvinceCode" minOccurs="0" maxOccurs="unbounded"/>
         *           &lt;xs:element type="xs:string" name="GovernmentBody" minOccurs="0"/>
         *         &lt;/xs:sequence>
         *       &lt;/xs:extension>
         *     &lt;/xs:complexContent>
         *   &lt;/xs:complexType>
         * &lt;/xs:element>
         * </pre>
         */
        public static class FeeExemption extends AssociatedObjectBaseType
            implements Serializable
        {
            private List<Fee> feeList = new ArrayList<Fee>();
            private List<CountryCodeType> countryCodeList = new ArrayList<CountryCodeType>();
            private List<String> provinceCodeList = new ArrayList<String>();
            private String governmentBody;

            /** 
             * Get the list of 'Fee' element items.
             * 
             * @return list
             */
            public List<Fee> getFeeList() {
                return feeList;
            }

            /** 
             * Set the list of 'Fee' element items.
             * 
             * @param list
             */
            public void setFeeList(List<Fee> list) {
                feeList = list;
            }

            /** 
             * Get the list of 'CountryCode' element items.
             * 
             * @return list
             */
            public List<CountryCodeType> getCountryCodeList() {
                return countryCodeList;
            }

            /** 
             * Set the list of 'CountryCode' element items.
             * 
             * @param list
             */
            public void setCountryCodeList(List<CountryCodeType> list) {
                countryCodeList = list;
            }

            /** 
             * Get the list of 'ProvinceCode' element items. Exempt province(s).
             * 
             * @return list
             */
            public List<String> getProvinceCodeList() {
                return provinceCodeList;
            }

            /** 
             * Set the list of 'ProvinceCode' element items. Exempt province(s).
             * 
             * @param list
             */
            public void setProvinceCodeList(List<String> list) {
                provinceCodeList = list;
            }

            /** 
             * Get the 'GovernmentBody' element value. Entity name.=notes=:
            1. This must be provided for certain exemptions in the Canadian market.
             * 
             * @return value
             */
            public String getGovernmentBody() {
                return governmentBody;
            }

            /** 
             * Set the 'GovernmentBody' element value. Entity name.=notes=:
            1. This must be provided for certain exemptions in the Canadian market.
             * 
             * @param governmentBody
             */
            public void setGovernmentBody(String governmentBody) {
                this.governmentBody = governmentBody;
            }
            /** 
             * Exemption(s) based on tax codes plus (optional) tax types within a tax code.
             * 
             * Schema fragment(s) for this class:
             * <pre>
             * &lt;xs:element xmlns:ns="http://www.iata.org/IATA/EDIST" xmlns:xs="http://www.w3.org/2001/XMLSchema" name="Fee" minOccurs="0" maxOccurs="unbounded">
             *   &lt;xs:complexType>
             *     &lt;xs:sequence>
             *       &lt;xs:element name="Code">
             *         &lt;xs:complexType>
             *           &lt;xs:simpleContent>
             *             &lt;xs:extension base="xs:string">
             *               &lt;xs:attribute type="xs:anySimpleType" use="optional" name="CollectionPoint"/>
             *             &lt;/xs:extension>
             *           &lt;/xs:simpleContent>
             *         &lt;/xs:complexType>
             *       &lt;/xs:element>
             *       &lt;xs:element type="xs:string" name="TaxType" minOccurs="0" maxOccurs="unbounded"/>
             *     &lt;/xs:sequence>
             *     &lt;xs:attributeGroup ref="ns:ObjAssociationAttrGroup"/>
             *   &lt;/xs:complexType>
             * &lt;/xs:element>
             * 
             * &lt;xs:attributeGroup xmlns:ns="http://www.iata.org/IATA/EDIST" xmlns:xs="http://www.w3.org/2001/XMLSchema" name="ObjAssociationAttrGroup">
             *   &lt;xs:attribute type="xs:string" use="optional" name="refs"/>
             * &lt;/xs:attributeGroup>
             * </pre>
             */
            public static class Fee implements Serializable
            {
                private String codeString;
                private String codeCollectionPoint;
                private List<String> taxTypeList = new ArrayList<String>();
                private String refs;

                /** 
                 * Get the extension value.
                 * 
                 * @return value
                 */
                public String getCodeString() {
                    return codeString;
                }

                /** 
                 * Set the extension value.
                 * 
                 * @param codeString
                 */
                public void setCodeString(String codeString) {
                    this.codeString = codeString;
                }

                /** 
                 * Get the 'CollectionPoint' attribute value. Airport code location for exempt ZP or XF taxes.
                Example: MIAFor maximum interoperability, it is recommended that IATA (three character) Airport/ City Code values be used. Use an IATA code or a proprietary string value.

                http://www.iata.org/publications/Pages/code-search.aspx
                 * 
                 * @return value
                 */
                public String getCodeCollectionPoint() {
                    return codeCollectionPoint;
                }

                /** 
                 * Set the 'CollectionPoint' attribute value. Airport code location for exempt ZP or XF taxes.
                Example: MIAFor maximum interoperability, it is recommended that IATA (three character) Airport/ City Code values be used. Use an IATA code or a proprietary string value.

                http://www.iata.org/publications/Pages/code-search.aspx
                 * 
                 * @param codeCollectionPoint
                 */
                public void setCodeCollectionPoint(String codeCollectionPoint) {
                    this.codeCollectionPoint = codeCollectionPoint;
                }

                /** 
                 * Get the list of 'TaxType' element items. Tax type(s) within the tax code.
                Examples: I, C
                 * 
                 * @return list
                 */
                public List<String> getTaxTypeList() {
                    return taxTypeList;
                }

                /** 
                 * Set the list of 'TaxType' element items. Tax type(s) within the tax code.
                Examples: I, C
                 * 
                 * @param list
                 */
                public void setTaxTypeList(List<String> list) {
                    taxTypeList = list;
                }

                /** 
                 * Get the 'refs' attribute value. Object association(s) between this object and any other object or metadata instance(s).
                 * 
                 * @return value
                 */
                public String getRefs() {
                    return refs;
                }

                /** 
                 * Set the 'refs' attribute value. Object association(s) between this object and any other object or metadata instance(s).
                 * 
                 * @param refs
                 */
                public void setRefs(String refs) {
                    this.refs = refs;
                }
            }
        }
    }
}
